@@ -8,7 +8,7 @@ kate_plugins_settings = {
     'createForm': {'text': 'Create Django Form', 'shortcut': 'Ctrl+Alt+F', 'menu': 'Edit', 'icon': None},
     'createModel': {'text': 'Create Django Model', 'shortcut': 'Ctrl+Alt+M', 'menu': 'Edit', 'icon': None},
     'importUrls': {'text': 'Template Django urls', 'shortcut': 'Ctrl+Alt+7', 'menu': 'Edit', 'icon': None},
-    'importViews': {'text': 'Create Django Model', 'shortcut': 'Ctrl+Alt+v', 'menu': 'Edit', 'icon': None},
+    'importViews': {'text': 'Template import views', 'shortcut': 'Ctrl+Alt+v', 'menu': 'Edit', 'icon': None},
     'insertReady': {'text': 'jQuery Ready', 'shortcut': 'Ctrl+J', 'menu': 'Edit', 'icon': None},
     'togglePrettyJsonFormat': {'text': 'Pretty Json', 'shortcut': 'Ctrl+Alt+J', 'menu': 'Edit', 'icon': None},
     'checkJslint': {'text': 'JSLint', 'shortcut': 'Alt+J', 'menu': 'Edit', 'icon': None},
