@@ -5,19 +5,21 @@ import kate
 from PyQt4 import QtCore
 
 from kate_settings_plugins import kate_plugins_settings
-from utils import is_mymetype_python
-from pyte_plugins.check_plugins.commons import showOk, showErrors, canCheckDocument, removeOldMarks
+
+from pyte_plugins.check_plugins.commons import (canCheckDocument, showOk,
+                                                removeOldMarks, showErrors)
 
 
 @kate.action(**kate_plugins_settings['parseCode'])
 def parseCode(doc=None):
-    if not canCheckDocument(doc, text_plain=True):
+    if not canCheckDocument(doc):
         return
     doc = doc or kate.activeDocument()
     text = unicode(doc.text())
+    text = text.encode('utf-8', 'ignore')
     mark_key = '%s-parse-python' % unicode(doc.url().path())
     try:
-        code = compiler.parse(text)
+        compiler.parse(text)
         removeOldMarks(mark_key, doc)
         showOk('Parse code Ok')
     except SyntaxError, e:
